Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6704)

Unified Diff: chrome/browser/prefs/preferences_service.h

Issue 2644893003: Unify Preferences Mojom Naming to PreferencesService (Closed)
Patch Set: / Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prefs/preferences_manager_unittest.cc ('k') | chrome/browser/prefs/preferences_service.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/prefs/preferences_service.h
diff --git a/chrome/browser/prefs/preferences_manager.h b/chrome/browser/prefs/preferences_service.h
similarity index 60%
rename from chrome/browser/prefs/preferences_manager.h
rename to chrome/browser/prefs/preferences_service.h
index 8f2272a0f8f03bb48f35b1ac3450294b16446d8b..eb837615a80eb1320179d63982d21e3df1369a69 100644
--- a/chrome/browser/prefs/preferences_manager.h
+++ b/chrome/browser/prefs/preferences_service.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_PREFS_PREFERENCES_MANAGER_H_
-#define CHROME_BROWSER_PREFS_PREFERENCES_MANAGER_H_
+#ifndef CHROME_BROWSER_PREFS_PREFERENCES_SERVICE_H_
+#define CHROME_BROWSER_PREFS_PREFERENCES_SERVICE_H_
#include <memory>
@@ -11,45 +11,45 @@
#include "services/preferences/public/interfaces/preferences.mojom.h"
namespace test {
-class PreferencesManagerTest;
+class PreferencesServiceTest;
}
class PrefChangeRegistrar;
class PrefService;
class Profile;
// Implementation of prefs::mojom::PreferencesManager that accepts a single
// prefs::mojom::PreferencesObserver.
//
// After calling AddObserver PreferencesManager will begin observing changes to
// the requested preferences, notifying the client of all changes.
-class PreferencesManager : public prefs::mojom::PreferencesManager {
+class PreferencesService : public prefs::mojom::PreferencesService {
public:
- PreferencesManager(prefs::mojom::PreferencesObserverPtr client,
+ PreferencesService(prefs::mojom::PreferencesServiceClientPtr client,
Profile* profile);
- ~PreferencesManager() override;
+ ~PreferencesService() override;
private:
- friend class test::PreferencesManagerTest;
+ friend class test::PreferencesServiceTest;
// PrefChangeRegistrar::NamedChangeCallback:
void PreferenceChanged(const std::string& preference_name);
- // mojom::PreferencesManager:
+ // mojom::PreferencesService:
void SetPreferences(
std::unique_ptr<base::DictionaryValue> preferences) override;
void Subscribe(const std::vector<std::string>& preferences) override;
// Tracks the desired preferences, and listens for updates.
std::unique_ptr<PrefChangeRegistrar> preferences_change_registrar_;
- prefs::mojom::PreferencesObserverPtr client_;
+ prefs::mojom::PreferencesServiceClientPtr client_;
PrefService* service_;
// Used to prevent notifying |client_| of changes caused by it calling
// SetPreferences.
bool setting_preferences_;
- DISALLOW_COPY_AND_ASSIGN(PreferencesManager);
+ DISALLOW_COPY_AND_ASSIGN(PreferencesService);
};
-#endif // CHROME_BROWSER_PREFS_PREFERENCES_MANAGER_H_
+#endif // CHROME_BROWSER_PREFS_PREFERENCES_SERVICE_H_
« no previous file with comments | « chrome/browser/prefs/preferences_manager_unittest.cc ('k') | chrome/browser/prefs/preferences_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -11,45 +11,45 @@
class PrefService;
class Profile;
-// Implementation of prefs::mojom::PreferencesManager that accepts a single
-// prefs::mojom::PreferencesObserver.
+// Implementation of prefs::mojom::PreferencesService that accepts a single
+// prefs::mojom::PreferencesServiceClient.
//
@@ -11,45 +11,45 @@
//
-// After calling AddObserver PreferencesManager will begin observing changes to
+// After calling AddObserver PreferencesService will begin observing changes to
// the requested preferences, notifying the client of all changes.
This is Rietveld 408576698